@@ -1,3 +1,6 @@
+# Import python libs
+import os
+
 # Import third party libs
 from cryptography.fernet import Fernet
 import yaml
@@ -17,6 +20,7 @@ def encrypt(hub, fn, key=None):
     with open(tfn, "wb+") as wfh:
         wfh.write(f.encrypt(msgpack.dumps(data)))
     ret["msg"] = f"New encrypted file created at: {tfn}\n"
+    key = key.decode()
     if print_key:
         ret["msg"] += f"The file was encrypted with this key:\n{key}"
     return ret
